@@ -262,6 +262,60 @@ try {
             }
             break;
             
+        case 'delete_backups':
+            $backupIds = $_POST['backup_ids'] ?? '';
+            if (!$backupIds) {
+                throw new Exception('Backup IDs required');
+            }
+            
+            // Parse comma-separated IDs
+            $ids = explode(',', $backupIds);
+            $ids = array_map('trim', $ids);
+            $ids = array_filter($ids); // Remove empty values
+            
+            if (empty($ids)) {
+                throw new Exception('No valid backup IDs provided');
+            }
+            
+            $engine = new BackupEngine();
+            $successCount = 0;
+            $failCount = 0;
+            $errors = [];
+            
+            foreach ($ids as $backupId) {
+                try {
+                    $result = $engine->deleteBackup($backupId, $username);
+                    if ($result) {
+                        $successCount++;
+                    } else {
+                        $failCount++;
+                        $errors[] = "Failed to delete backup ID: $backupId";
+                    }
+                } catch (Exception $e) {
+                    $failCount++;
+                    $errors[] = "Error deleting backup ID $backupId: " . $e->getMessage();
+                }
+            }
+            
+            if ($failCount === 0) {
+                echo json_encode([
+                    'success' => true, 
+                    'message' => "$successCount backup(s) deleted successfully"
+                ]);
+            } else if ($successCount === 0) {
+                echo json_encode([
+                    'success' => false, 
+                    'message' => "Failed to delete all backups: " . implode(', ', $errors)
+                ]);
+            } else {
+                echo json_encode([
+                    'success' => true, 
+                    'message' => "$successCount backup(s) deleted successfully, $failCount failed",
+                    'errors' => $errors
+                ]);
+            }
+            break;
+            
         case 'download':
             $backupId = $_GET['backup_id'] ?? '';
             if (!$backupId) {
