@@ -451,11 +451,29 @@ $stats = [
                         </div>
                     </div>
                     
+                    <!-- Bulk Actions -->
+                    <div class="row mb-3" id="bulkActions" style="display: none;">
+                        <div class="col-12">
+                            <div class="alert alert-light border">
+                                <span id="selectedCount">0</span> backup(s) selected
+                                <button class="btn btn-sm btn-outline-danger ms-3" onclick="deleteSelectedBackups()">
+                                    <i class="fa fa-trash"></i> Delete Selected
+                                </button>
+                                <button class="btn btn-sm btn-outline-secondary ms-2" onclick="clearSelection()">
+                                    Clear Selection
+                                </button>
+                            </div>
+                        </div>
+                    </div>
+                    
                     <!-- Backup Table -->
                     <div class="table-responsive">
                         <table class="table table-hover">
                             <thead>
                                 <tr>
+                                    <th style="width: 40px;">
+                                        <input type="checkbox" id="selectAllBackups" onchange="toggleSelectAll()" title="Select all">
+                                    </th>
                                     <th>Name</th>
                                     <th>Type</th>
                                     <th>User</th>
@@ -788,23 +806,52 @@ function downloadBackup(backupId) {
 }
 
 function deleteBackup(backupId) {
-    if (confirm('Are you sure you want to delete this backup?')) {
+    deleteBackups([backupId]);
+}
+
+function deleteSelectedBackups() {
+    const selectedCheckboxes = document.querySelectorAll('.backup-checkbox:checked');
+    const backupIds = Array.from(selectedCheckboxes).map(cb => cb.value);
+    
+    if (backupIds.length === 0) {
+        showAlert('Please select at least one backup to delete.', 'warning');
+        return;
+    }
+    
+    deleteBackups(backupIds);
+}
+
+function deleteBackups(backupIds) {
+    const count = backupIds.length;
+    const message = count === 1 ? 'Are you sure you want to delete this backup?' : `Are you sure you want to delete these ${count} backups?`;
+    
+    if (confirm(message)) {
+        // Show loading state
+        showAlert('Deleting backup(s)...', 'info');
+        
         fetch('api/backup-actions.php', {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
                 'X-CSRF-Token': csrfToken
             },
-            body: `action=delete_backup&backup_id=${backupId}`
+            body: `action=delete_backups&backup_ids=${backupIds.join(',')}`
         })
         .then(response => response.json())
         .then(data => {
             if (data.success) {
-                showAlert('Backup deleted successfully!', 'success');
-                setTimeout(() => location.reload(), 1000);
+                showAlert(`${count === 1 ? 'Backup' : 'Backups'} deleted successfully!`, 'success');
+                // Reload the current page without losing search/filter state
+                loadBackups(currentPage);
+                // Clear any selected checkboxes
+                document.querySelectorAll('.backup-checkbox:checked').forEach(cb => cb.checked = false);
+                updateBulkActionButtons();
             } else {
                 showAlert('Error: ' + data.message, 'danger');
             }
+        })
+        .catch(error => {
+            showAlert('Error deleting backup(s): ' + error.message, 'danger');
         });
     }
 }
@@ -1139,7 +1186,22 @@ function convertToLocalTime() {
                 // Store original server time for tooltip
                 const originalText = element.textContent.trim();
                 
-                const date = new Date(utcTime);
+                // Handle MySQL datetime format (YYYY-MM-DD HH:MM:SS)
+                // Assume it's UTC time from the database
+                let date;
+                if (utcTime.match(/^\d{4}-\d{2}-\d{2} \d{2}:\d{2}:\d{2}$/)) {
+                    // MySQL datetime format - treat as UTC
+                    date = new Date(utcTime + ' UTC');
+                } else {
+                    // Try to parse as is
+                    date = new Date(utcTime);
+                }
+                
+                if (isNaN(date.getTime())) {
+                    console.warn('Invalid date format:', utcTime);
+                    return;
+                }
+                
                 const hasSeconds = originalText.includes(':') && originalText.split(':').length > 2;
                 
                 const localTime = date.toLocaleString(undefined, {
@@ -1153,7 +1215,7 @@ function convertToLocalTime() {
                 });
                 
                 element.textContent = localTime;
-                element.title = `Server time: ${originalText}`;
+                element.title = `Server time (UTC): ${originalText}`;
                 element.setAttribute('data-converted', 'true');
             } catch (error) {
                 console.warn('Failed to convert time:', utcTime, error);
@@ -1196,7 +1258,7 @@ function loadBackups(page = 1) {
     if (statusFilter) params.append('status', statusFilter);
     
     // Show loading indicator
-    document.getElementById('backupsList').innerHTML = '<tr><td colspan="8" class="text-center"><i class="fa fa-spinner fa-spin"></i> Loading backups...</td></tr>';
+    document.getElementById('backupsList').innerHTML = '<tr><td colspan="9" class="text-center"><i class="fa fa-spinner fa-spin"></i> Loading backups...</td></tr>';
     
     fetch('api/backup-actions.php?' + params.toString())
         .then(response => response.json())
@@ -1220,13 +1282,21 @@ function displayBackups(backups) {
     const tbody = document.getElementById('backupsList');
     
     if (backups.length === 0) {
-        tbody.innerHTML = '<tr><td colspan="8" class="text-center text-muted">No backups found</td></tr>';
+        tbody.innerHTML = '<tr><td colspan="9" class="text-center text-muted">No backups found</td></tr>';
         return;
     }
     
     tbody.innerHTML = backups.map(backup => `
         <tr>
-            <td>${escapeHtml(backup.backup_name)}</td>
+            <td>
+                ${<?php echo $isRoot ? 'true' : 'false'; ?> || backup.user === '<?php echo AUTH_USER; ?>' ? `
+                    <input type="checkbox" class="backup-checkbox" value="${backup.id}" onchange="updateBulkActionButtons()">
+                ` : ''}
+            </td>
+            <td>
+                <i class="fa fa-${getBackupTypeIconJS(backup.backup_type)}"></i>
+                ${escapeHtml(backup.backup_name)}
+            </td>
             <td>
                 <span class="badge bg-${getBackupTypeColorJS(backup.backup_type)}">
                     ${backup.backup_type.charAt(0).toUpperCase() + backup.backup_type.slice(1)}
@@ -1241,7 +1311,7 @@ function displayBackups(backups) {
                 </span>
             </td>
             <td>
-                <span class="local-time" data-utc="${new Date(backup.started_at).toISOString()}">
+                <span class="local-time" data-utc="${backup.started_at}">
                     ${backup.started_at}
                 </span>
             </td>
@@ -1382,6 +1452,54 @@ document.getElementById('backupSearch').addEventListener('keypress', function(e)
     }
 });
 
+// Multi-select functionality
+function toggleSelectAll() {
+    const selectAll = document.getElementById('selectAllBackups');
+    const checkboxes = document.querySelectorAll('.backup-checkbox');
+    
+    checkboxes.forEach(checkbox => {
+        checkbox.checked = selectAll.checked;
+    });
+    
+    updateBulkActionButtons();
+}
+
+function updateBulkActionButtons() {
+    const selectedCheckboxes = document.querySelectorAll('.backup-checkbox:checked');
+    const bulkActions = document.getElementById('bulkActions');
+    const selectedCount = document.getElementById('selectedCount');
+    const selectAllCheckbox = document.getElementById('selectAllBackups');
+    const allCheckboxes = document.querySelectorAll('.backup-checkbox');
+    
+    // Update selected count
+    selectedCount.textContent = selectedCheckboxes.length;
+    
+    // Show/hide bulk actions
+    if (selectedCheckboxes.length > 0) {
+        bulkActions.style.display = 'block';
+    } else {
+        bulkActions.style.display = 'none';
+    }
+    
+    // Update select all checkbox state
+    if (selectedCheckboxes.length === 0) {
+        selectAllCheckbox.checked = false;
+        selectAllCheckbox.indeterminate = false;
+    } else if (selectedCheckboxes.length === allCheckboxes.length) {
+        selectAllCheckbox.checked = true;
+        selectAllCheckbox.indeterminate = false;
+    } else {
+        selectAllCheckbox.checked = false;
+        selectAllCheckbox.indeterminate = true;
+    }
+}
+
+function clearSelection() {
+    document.querySelectorAll('.backup-checkbox:checked').forEach(cb => cb.checked = false);
+    document.getElementById('selectAllBackups').checked = false;
+    updateBulkActionButtons();
+}
+
 // Update help text for global targets
 <?php if ($isRoot): ?>
 document.getElementById('targetGlobal').addEventListener('change', function() {
